@@ -5,7 +5,7 @@
 // or the GNU General Public License version 2 or later 
 // <http://www.gnu.org/copyleft/gpl.html>
 //
-// $Id: strncasecmp2.c,v 1.1 2008/06/04 15:01:39 sebdiaz Exp $
+// $Id: strncasecmp2.c,v 1.2 2014/04/17 20:27:24 sebdiaz Exp $
 //
 
 #ifdef HAVE_CONFIG_H
@@ -16,6 +16,7 @@
 
 //*****************************************************************************
 //
+#ifndef HAVE_STRNCASECMP
 int strncasecmp(const char *str1, const char *str2, int n)
 {
     if (!str1 && !str2)
@@ -39,3 +40,4 @@ int strncasecmp(const char *str1, const char *str2, int n)
     return n == 0 ? 0 :
 	tolower((unsigned char)*str1) - tolower((unsigned char)*str2);
 }
+#endif
\ No newline at end of file
