@@ -8,7 +8,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: bt_cursor.c,v 1.5 2000/10/25 12:32:19 loic Exp $";
+static const char revid[] = "$Id: bt_cursor.c,v 1.6 2014/04/17 20:27:24 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -1140,18 +1140,17 @@ __bam_c_put(dbc, key, data, flags, pgnop)
 	DB *dbp;
 	DBT dbt;
 	u_int32_t iiop;
-	int cmp, exact, needkey, ret, stack;
+	int cmp, exact, ret, stack;
 	void *arg;
 
 	dbp = dbc->dbp;
 	cp = (BTREE_CURSOR *)dbc->internal;
 
-split:	needkey = ret = stack = 0;
+split:	ret = stack = 0;
 	switch (flags) {
 	case DB_AFTER:
 	case DB_BEFORE:
 	case DB_CURRENT:
-		needkey = 1;
 		iiop = flags;
 
 		/*
@@ -1354,6 +1353,11 @@ CDB___bam_c_rget(dbc, data, flags)
 	DBT *data;
 	u_int32_t flags;
 {
+	if (flags>0)
+	{
+	  flags=flags+1;
+	  flags=flags-1;
+	}
 	BTREE_CURSOR *cp;
 	DB *dbp;
 	DBT dbt;
@@ -1429,11 +1433,9 @@ __bam_c_first(dbc)
 	DBC *dbc;
 {
 	BTREE_CURSOR *cp;
-	DB *dbp;
 	db_pgno_t pgno;
 	int ret;
 
-	dbp = dbc->dbp;
 	cp = (BTREE_CURSOR *)dbc->internal;
 	ret = 0;
 
@@ -1474,11 +1476,9 @@ __bam_c_last(dbc)
 	DBC *dbc;
 {
 	BTREE_CURSOR *cp;
-	DB *dbp;
 	db_pgno_t pgno;
 	int ret;
 
-	dbp = dbc->dbp;
 	cp = (BTREE_CURSOR *)dbc->internal;
 	ret = 0;
 
@@ -1525,13 +1525,11 @@ __bam_c_next(dbc, initial_move)
 	int initial_move;
 {
 	BTREE_CURSOR *cp;
-	DB *dbp;
 	db_indx_t adjust;
 	db_lockmode_t lock_mode;
 	db_pgno_t pgno;
 	int ret;
 
-	dbp = dbc->dbp;
 	cp = (BTREE_CURSOR *)dbc->internal;
 	ret = 0;
 
@@ -1595,13 +1593,11 @@ __bam_c_prev(dbc)
 	DBC *dbc;
 {
 	BTREE_CURSOR *cp;
-	DB *dbp;
 	db_indx_t adjust;
 	db_lockmode_t lock_mode;
 	db_pgno_t pgno;
 	int ret;
 
-	dbp = dbc->dbp;
 	cp = (BTREE_CURSOR *)dbc->internal;
 	ret = 0;
 
