@@ -8,7 +8,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: bt_rec.c,v 1.4 2000/06/28 16:47:00 loic Exp $";
+static const char revid[] = "$Id: bt_rec.c,v 1.5 2014/04/17 20:27:25 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -42,6 +42,10 @@ CDB___bam_pg_alloc_recover(dbenv, dbtp, lsnp, op, info)
 	db_recops op;
 	void *info;
 {
+	if (info==NULL)
+	{
+	  info=NULL;
+	}
 	__bam_pg_alloc_args *argp;
 	DB *file_dbp;
 	DBC *dbc;
@@ -168,6 +172,10 @@ CDB___bam_pg_free_recover(dbenv, dbtp, lsnp, op, info)
 	db_recops op;
 	void *info;
 {
+	if (info==NULL)
+	{
+	  info=NULL;
+	}
 	__bam_pg_free_args *argp;
 	DB *file_dbp;
 	DBC *dbc;
@@ -277,6 +285,10 @@ CDB___bam_split_recover(dbenv, dbtp, lsnp, op, info)
 	db_recops op;
 	void *info;
 {
+	if (info==NULL)
+	{
+	  info=NULL;
+	}
 	__bam_split_args *argp;
 	DB *file_dbp;
 	DBC *dbc;
@@ -582,6 +594,10 @@ CDB___bam_rsplit_recover(dbenv, dbtp, lsnp, op, info)
 	db_recops op;
 	void *info;
 {
+	if (info==NULL)
+	{
+	  info=NULL;
+	}
 	__bam_rsplit_args *argp;
 	DB *file_dbp;
 	DBC *dbc;
@@ -683,6 +699,10 @@ CDB___bam_adj_recover(dbenv, dbtp, lsnp, op, info)
 	db_recops op;
 	void *info;
 {
+	if (info==NULL)
+	{
+	  info=NULL;
+	}
 	__bam_adj_args *argp;
 	DB *file_dbp;
 	DBC *dbc;
@@ -751,6 +771,10 @@ CDB___bam_cadjust_recover(dbenv, dbtp, lsnp, op, info)
 	db_recops op;
 	void *info;
 {
+	if (info==NULL)
+	{
+	  info=NULL;
+	}
 	__bam_cadjust_args *argp;
 	DB *file_dbp;
 	DBC *dbc;
@@ -826,6 +850,10 @@ CDB___bam_cdel_recover(dbenv, dbtp, lsnp, op, info)
 	db_recops op;
 	void *info;
 {
+	if (info==NULL)
+	{
+	  info=NULL;
+	}
 	__bam_cdel_args *argp;
 	DB *file_dbp;
 	DBC *dbc;
@@ -889,6 +917,10 @@ CDB___bam_repl_recover(dbenv, dbtp, lsnp, op, info)
 	db_recops op;
 	void *info;
 {
+	if (info==NULL)
+	{
+	  info=NULL;
+	}
 	__bam_repl_args *argp;
 	BKEYDATA *bk;
 	DB *file_dbp;
@@ -996,6 +1028,10 @@ CDB___bam_root_recover(dbenv, dbtp, lsnp, op, info)
 	db_recops op;
 	void *info;
 {
+	if (info==NULL)
+	{
+	  info=NULL;
+	}
 	__bam_root_args *argp;
 	BTMETA *meta;
 	DB *file_dbp;
