@@ -8,7 +8,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: bt_recno.c,v 1.3 2000/06/28 16:47:00 loic Exp $";
+static const char revid[] = "$Id: bt_recno.c,v 1.4 2014/04/17 20:27:25 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -388,6 +388,10 @@ CDB___ram_c_get(dbc, key, data, flags, pgnop)
 	u_int32_t flags;
 	db_pgno_t *pgnop;
 {
+	if (pgnop==NULL)
+	{
+	  pgnop=NULL;
+	}
 	BTREE_CURSOR *cp;
 	DB *dbp;
 	int cmp, exact, ret;
@@ -614,6 +618,10 @@ CDB___ram_c_put(dbc, key, data, flags, pgnop)
 	u_int32_t flags;
 	db_pgno_t *pgnop;
 {
+	if (pgnop==NULL)
+	{
+	  pgnop=NULL;
+	}
 	BTREE_CURSOR *cp;
 	DB *dbp;
 	int exact, ret, t_ret;
@@ -787,13 +795,11 @@ __ram_update(dbc, recno, can_create)
 	int can_create;
 {
 	BTREE *t;
-	BTREE_CURSOR *cp;
 	DB *dbp;
 	db_recno_t nrecs;
 	int ret;
 
 	dbp = dbc->dbp;
-	cp = (BTREE_CURSOR *)dbc->internal;
 	t = dbp->bt_internal;
 
 	/*
@@ -1086,7 +1092,6 @@ __ram_fmap(dbc, top)
 	db_recno_t top;
 {
 	BTREE *t;
-	BTREE_CURSOR *cp;
 	DB *dbp;
 	DBT data;
 	db_recno_t recno;
@@ -1095,7 +1100,6 @@ __ram_fmap(dbc, top)
 	int is_modified, ret;
 
 	dbp = dbc->dbp;
-	cp = (BTREE_CURSOR *)dbc->internal;
 	t = dbp->bt_internal;
 
 	if ((ret = CDB___bam_nrecs(dbc, &recno)) != 0)
