@@ -40,7 +40,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: db.c,v 1.8 2000/06/29 11:57:01 loic Exp $";
+static const char revid[] = "$Id: db.c,v 1.9 2014/04/17 20:27:26 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -335,10 +335,8 @@ CDB___db_dbopen(dbp, name, flags, mode, meta_pgno)
 	int mode;
 	db_pgno_t meta_pgno;
 {
-	DB_ENV *dbenv;
 	int ret, retinfo;
 
-	dbenv = dbp->dbenv;
 
 	/* Set up the underlying file. */
 	if ((ret = __db_file_setup(dbp,
@@ -1015,7 +1013,7 @@ open_retry:
 	  if ((ret = CDB___os_seek(dbenv, fhp, disk_pagesize, 
 				   meta_pgno, 0, 0, DB_OS_SEEK_SET)) != 0)
 	    goto err_msg;
-	  if ((ret = CDB___memp_cmpr_read_meta(dbenv, fhp, mbuf, sizeof(mbuf), &nr)) != 0)
+	  if ((ret = CDB___memp_cmpr_read_meta(dbenv, fhp, mbuf, sizeof(mbuf), (ssize_t*)&nr)) != 0)
 	    goto err_msg;
 	}
 
@@ -1213,7 +1211,7 @@ __db_set_pgsize(dbp, fhp, name)
 	 * by the compression factor.
 	 */
 	if(F_ISSET(dbp, DB_AM_CMPR)) {
-	  if(iopsize < DB_CMPR_MULTIPLY(dbenv, DB_MIN_PGSIZE))
+	  if(iopsize < (u_int32_t)DB_CMPR_MULTIPLY(dbenv, DB_MIN_PGSIZE))
 	    iopsize = DB_CMPR_MULTIPLY(dbenv, DB_MIN_PGSIZE);
 	}
 
@@ -1540,14 +1538,14 @@ __db_subdb_remove(dbp, name, subdb)
 	const char *name, *subdb;
 {
 	DB *mdbp;
-	DBC *dbc;
+	
 	DB_ENV *dbenv;
 	DB_LOCK remove_lock;
 	db_pgno_t meta_pgno;
 	int ret, t_ret;
 
 	mdbp = NULL;
-	dbc = NULL;
+	
 	dbenv = dbp->dbenv;
 
 	/* Start the transaction. */
@@ -1758,13 +1756,11 @@ __db_subdb_rename(dbp, name, subdb, newname)
 	const char *name, *subdb, *newname;
 {
 	DB *mdbp;
-	DBC *dbc;
 	DB_ENV *dbenv;
 	DB_LOCK remove_lock;
 	int ret, t_ret;
 
 	mdbp = NULL;
-	dbc = NULL;
 	dbenv = dbp->dbenv;
 
 	/* Start the transaction. */
