@@ -8,7 +8,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: db_join.c,v 1.4 2000/06/28 16:47:01 loic Exp $";
+static const char revid[] = "$Id: db_join.c,v 1.5 2014/04/17 20:27:27 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -254,6 +254,7 @@ __db_join_put(dbc, key, data, flags)
 	DBT *data;
 	u_int32_t flags;
 {
+	if(key||data||flags){}
 	PANIC_CHECK(dbc->dbp->dbenv);
 
 	COMPQUIET(key, NULL);
@@ -267,6 +268,7 @@ __db_join_del(dbc, flags)
 	DBC *dbc;
 	u_int32_t flags;
 {
+	if(flags){}
 	PANIC_CHECK(dbc->dbp->dbenv);
 
 	COMPQUIET(flags, 0);
