@@ -8,7 +8,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: db_pr.c,v 1.3 2000/06/28 16:47:01 loic Exp $";
+static const char revid[] = "$Id: db_pr.c,v 1.4 2014/04/17 20:27:27 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -127,6 +127,7 @@ __db_prdb(dbp, fp, flags)
 	FILE *fp;
 	u_int32_t flags;
 {
+	if (flags){}
 	static const FN fn[] = {
 		{ DB_AM_DISCARD,	"discard cached pages" },
 		{ DB_AM_DUP,		"duplicates" },
@@ -449,7 +450,7 @@ CDB___db_prpage(dbp, h, flags)
 {
 	BINTERNAL *bi;
 	BKEYDATA *bk;
-	BTREE *t;
+	
 	FILE *fp;
 	HOFFPAGE a_hkd;
 	QAMDATA *qp, *qep;
@@ -522,7 +523,7 @@ CDB___db_prpage(dbp, h, flags)
 		return (0);
 	}
 
-	t = dbp->bt_internal;
+	
 
 	s = "\t";
 	if (TYPE(h) != P_IBTREE && TYPE(h) != P_IRECNO) {
