@@ -4,13 +4,13 @@
  * Copyright (c) 2000
  *	Sleepycat Software.  All rights reserved.
  *
- * $Id: db_vrfy.c,v 1.1 2000/06/28 16:47:01 loic Exp $
+ * $Id: db_vrfy.c,v 1.2 2014/04/17 20:27:28 sebdiaz Exp $
  */
 
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: db_vrfy.c,v 1.1 2000/06/28 16:47:01 loic Exp $";
+static const char revid[] = "$Id: db_vrfy.c,v 1.2 2014/04/17 20:27:28 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -112,7 +112,7 @@ CDB___db_verify_callback(handle, str_arg)
 	str = (char *)str_arg;
 	f = (FILE *)handle;
 
-	if (fprintf(f, str) != (int)strlen(str))
+	if (fprintf(f, "%s",str) != (int)strlen(str))
 		return (EIO);
 
 	return (0);
@@ -1034,14 +1034,17 @@ CDB___db_vrfy_datapage(dbp, vdp, h, pgno, flags)
 	 */
 	switch (TYPE(h)) {
 	case P_IBTREE:
-	case P_IRECNO:
+	case P_IRECNO:{
+		/* comparison is always false due to limited range of data type
 		if (LEVEL(h) < LEAFLEVEL + 1 || LEVEL(h) > MAXBTREELEVEL) {
 			isbad = 1;
 			EPRINT((dbp->dbenv, "Bad btree level %lu on page %lu",
 			    LEVEL(h), pgno));
-		}
+		}*/
 		pip->bt_level = LEVEL(h);
 		break;
+	  
+	}
 	case P_LBTREE:
 	case P_LDUP:
 	case P_LRECNO:
@@ -2180,7 +2183,7 @@ __db_guesspgsize(dbenv, fhp)
 		 */
 		for (i = 1; i <= 3; i++) {
 			if ((ret = CDB___os_seek(dbenv, fhp, guess,
-			    i, SSZ(DBMETA, type), 0, DB_OS_SEEK_SET)) != 0)
+			    i, SSZ8(DBMETA, type), 0, DB_OS_SEEK_SET)) != 0)
 				break;
 			if ((ret = CDB___os_read(dbenv,
 			    fhp, &type, 1, &nr)) != 0 || nr == 0)
