@@ -43,7 +43,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: hash.c,v 1.5 2000/06/28 16:47:01 loic Exp $";
+static const char revid[] = "$Id: hash.c,v 1.6 2014/04/17 20:27:28 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -548,6 +548,7 @@ __ham_c_close(dbc, root_pgno, rmroot)
 	db_pgno_t root_pgno;
 	int *rmroot;
 {
+	if(rmroot){}
 	HASH_CURSOR *hcp;
 	HKEYDATA *dp;
 	int dirty, doroot, gotmeta, ret, t_ret;
@@ -699,7 +700,8 @@ __ham_c_del(dbc)
 
 	if (F_ISSET(hcp, H_ISDUP)) { /* On-page duplicate. */
 		if (hcp->dup_off == 0 &&
-		    DUP_SIZE(hcp->dup_len) == LEN_HDATA(hcp->page,
+		  
+		    (unsigned int)DUP_SIZE(hcp->dup_len) == (unsigned int)LEN_HDATA(hcp->page,
 		    hcp->hdr->dbmeta.pagesize, hcp->indx))
 			ret = CDB___ham_del_pair(dbc, 1);
 		else {
