@@ -38,7 +38,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: hash_dup.c,v 1.5 2000/06/28 16:47:01 loic Exp $";
+static const char revid[] = "$Id: hash_dup.c,v 1.6 2014/04/17 20:27:29 sebdiaz Exp $";
 #endif /* not lint */
 
 /*
@@ -475,7 +475,7 @@ __ham_check_move(dbc, add_len)
 	 */
 
 	new_datalen = ISBIG(hcp, new_datalen) ?
-	    HOFFDUP_SIZE : HKEYDATA_SIZE(new_datalen);
+	    (size_t)HOFFDUP_SIZE : (size_t)HKEYDATA_SIZE(new_datalen);
 
 	next_pagep = NULL;
 	for (next_pgno = NEXT_PGNO(hcp->page); next_pgno != PGNO_INVALID;
@@ -591,7 +591,7 @@ CDB___ham_move_offpage(dbc, pagep, ndx, pgno)
 	db_pgno_t pgno;
 {
 	DB *dbp;
-	HASH_CURSOR *hcp;
+	
 	DBT new_dbt;
 	DBT old_dbt;
 	HOFFDUP od;
@@ -600,7 +600,7 @@ CDB___ham_move_offpage(dbc, pagep, ndx, pgno)
 	u_int8_t *src;
 
 	dbp = dbc->dbp;
-	hcp = (HASH_CURSOR *)dbc->internal;
+	
 	od.type = H_OFFDUP;
 	UMRW(od.unused[0]);
 	UMRW(od.unused[1]);
