@@ -8,7 +8,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: lock.c,v 1.3 2000/06/28 16:47:01 loic Exp $";
+static const char revid[] = "$Id: lock.c,v 1.4 2014/04/17 20:27:30 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -667,7 +667,7 @@ __lock_put_nolock(dbenv, lock, runp)
 	struct __db_lock *lockp;
 	DB_LOCKREGION *region;
 	DB_LOCKTAB *lt;
-	u_int32_t locker;
+	
 	int ret;
 
 	lt = dbenv->lk_handle;
@@ -679,7 +679,7 @@ __lock_put_nolock(dbenv, lock, runp)
 		return(EACCES);
 	}
 
-	locker = lockp->holder;
+	
 	ret = __lock_put_internal(lt,
 	    lockp, lock->ndx, DB_LOCK_UNLINK | DB_LOCK_FREE);
 
@@ -707,11 +707,12 @@ CDB___lock_downgrade(dbenv, lock, new_mode, flags)
 	db_lockmode_t new_mode;
 	u_int32_t flags;
 {
+      if(flags){}	
 	struct __db_lock *lockp;
 	DB_LOCKOBJ *obj;
 	DB_LOCKREGION *region;
 	DB_LOCKTAB *lt;
-	int ret;
+	
 
 	COMPQUIET(flags, 0);
 
@@ -725,7 +726,6 @@ CDB___lock_downgrade(dbenv, lock, new_mode, flags)
 	lockp = (struct __db_lock *)R_ADDR(&lt->reginfo, lock->off);
 	if (lock->gen != lockp->gen) {
 		CDB___db_err(dbenv, __db_lock_invalid, "lock_downgrade");
-		ret = EACCES;
 		goto out;
 	}
 
@@ -750,10 +750,10 @@ __lock_put_internal(lt, lockp, obj_ndx, flags)
 {
 	DB_LOCKOBJ *sh_obj;
 	DB_LOCKREGION *region;
-	int no_reclaim, ret, state_changed;
+	int  ret, state_changed;
 
 	region = lt->reginfo.primary;
-	no_reclaim = ret = state_changed = 0;
+	
 
 	if (!OBJ_LINKS_VALID(lockp)) {
 		/*
@@ -847,13 +847,13 @@ __lock_checklocker(lt, lockp, locker, flags, freed)
 	u_int32_t locker, flags;
 	int *freed;
 {
-	DB_ENV *dbenv;
+	
 	DB_LOCKER *sh_locker;
 	DB_LOCKREGION *region;
 	u_int32_t indx;
 	int ret;
 
-	dbenv = lt->dbenv;
+	
 	region = lt->reginfo.primary;
 	ret = 0;
 
@@ -1050,11 +1050,11 @@ CDB___lock_getlocker(lt, locker, indx, create, retp)
 	int create;
 	DB_LOCKER **retp;
 {
-	DB_ENV *dbenv;
+	
 	DB_LOCKER *sh_locker;
 	DB_LOCKREGION *region;
 
-	dbenv = lt->dbenv;
+	
 	region = lt->reginfo.primary;
 
 	HASHLOOKUP(lt->locker_tab,
