@@ -7,7 +7,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: mp_bh.c,v 1.8 2000/06/30 08:35:12 loic Exp $";
+static const char revid[] = "$Id: mp_bh.c,v 1.9 2014/04/17 20:27:30 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -211,7 +211,7 @@ CDB___memp_pgread(dbmfp, bhp, can_create)
 		db_io.buf = bhp->buf;
 
 		if(F_ISSET(dbmfp, MP_CMPR)) {
-		  ret = CDB___memp_cmpr(dbmfp, bhp, &db_io, DB_IO_READ, &nr);
+		  ret = CDB___memp_cmpr(dbmfp, bhp, &db_io, DB_IO_READ, (ssize_t*)&nr);
 		} else {
 		  ret = CDB___os_io(dbenv, &db_io, DB_IO_READ, &nr);
 		}
@@ -432,7 +432,7 @@ CDB___memp_pgwrite(dbmp, dbmfp, bhp, restartp, wrotep)
 	}
 #endif /* DEBUG */
 	if(F_ISSET(dbmfp, MP_CMPR)) {
-	  ret = CDB___memp_cmpr(dbmfp, bhp, &db_io, DB_IO_WRITE, &nw);
+	  ret = CDB___memp_cmpr(dbmfp, bhp, &db_io, DB_IO_WRITE, (ssize_t*)&nw);
 	} else {
 	  if(db_io.pgno == PGNO_BASE_MD) {
 	    /*
