@@ -128,7 +128,7 @@ CDB___memp_cmpr(dbmfp, bhp, db_io, flag, niop)
   switch (flag) {
   case DB_IO_READ:
     if(db_io->pgno == PGNO_BASE_MD) {
-      ret = CDB___os_io(dbenv, db_io, DB_IO_READ, niop);
+      ret = CDB___os_io(dbenv, db_io, DB_IO_READ, ( size_t *)niop);
       *niop = CMPR_MULTIPLY(*niop);
     } else 
       ret = CDB___memp_cmpr_read(dbmfp, bhp, db_io, niop);
@@ -146,14 +146,14 @@ CDB___memp_cmpr(dbmfp, bhp, db_io, flag, niop)
       size_t orig_bytes = db_io->bytes;
       db_io->bytes = DBMETASIZE;
       for(db_io->pagesize = DBMETASIZE; db_io->pagesize < required; db_io->pagesize <<= 1) {
-	ret = CDB___os_io(dbenv, db_io, DB_IO_WRITE, niop);
+	ret = CDB___os_io(dbenv, db_io, DB_IO_WRITE, (size_t *) niop);
 	if(ret != 0 || *niop != DBMETASIZE)
 	  break;
       }
       db_io->bytes = orig_bytes;
       db_io->pagesize = required;
       if(ret == 0)
-	ret = CDB___os_io(dbenv, db_io, DB_IO_WRITE, niop);
+	ret = CDB___os_io(dbenv, db_io, DB_IO_WRITE, (size_t *)niop);
       *niop = CMPR_MULTIPLY(*niop);
     } else
       ret = CDB___memp_cmpr_write(dbmfp, bhp, db_io, niop);
@@ -181,12 +181,12 @@ CDB___memp_cmpr_read_meta(dbenv, fhp, buff, buff_length, nrp)
 {
   CMPR cmpr;
   int ret;
-  int i;
+  size_t i;
 
-  if((ret = CDB___os_read(dbenv, fhp, buff, buff_length, nrp)) != 0)
+  if((ret = CDB___os_read(dbenv, fhp, buff, buff_length, (size_t *)nrp)) != 0)
     goto err;
 
-  if(*nrp != buff_length)
+  if((size_t)*nrp != buff_length)
     goto err;
   
   /*
@@ -241,13 +241,13 @@ CDB___memp_cmpr_read(dbmfp, bhp, db_io, niop)
   /*
    * Read first page (if no overflow, this is the only one)
    */
-  ret = CDB___os_io(dbenv, db_io, DB_IO_READ, niop);
+  ret = CDB___os_io(dbenv, db_io, DB_IO_READ, (size_t*)niop);
 
   /*
    * An error or partial read on the first page means that we're not
    * going anywhere.
    */
-  if(ret || *niop < db_io->pagesize)
+  if(ret || (size_t)*niop < db_io->pagesize)
     goto err;
 
   /*
@@ -318,8 +318,8 @@ CDB___memp_cmpr_read(dbmfp, bhp, db_io, niop)
       /*
        * Read data from extra page.
        */
-      if((ret = CDB___os_io(dbenv, db_io, DB_IO_READ, niop)) != 0 ||
-	 *niop != db_io->pagesize) {
+      if((ret = CDB___os_io(dbenv, db_io, DB_IO_READ, (size_t*)niop)) != 0 ||
+	 (size_t)*niop != db_io->pagesize) {
 	ret = EIO;
 	goto err;
       }
@@ -449,7 +449,7 @@ CDB___memp_cmpr_write(dbmfp, bhp, db_io, niop)
   /*
    * This can never happen.
    */
-  if(buffcmpr_length > DB_CMPR_PAGESIZE(db_io) * CMPR_MAX) {
+  if((size_t)buffcmpr_length > (size_t)(DB_CMPR_PAGESIZE(db_io) * CMPR_MAX)) {
     CDB___db_err(dbmfp->dbmp->dbenv, "CDB___memp_cmpr_write: compressed data is too big at pgno = %ld", db_io->pgno);
     ret = CDB___db_panic(dbmfp->dbmp->dbenv, EINVAL);
     goto err;
@@ -461,8 +461,8 @@ CDB___memp_cmpr_write(dbmfp, bhp, db_io, niop)
 
   /* write pages until the whole compressed data is written */ 
   do {
-    int length = buffcmpr_length - (buffp - buffcmpr);
-    int copy_length = length > DB_CMPR_PAGESIZE(db_io) ? DB_CMPR_PAGESIZE(db_io) : length;
+    size_t length = buffcmpr_length - (buffp - buffcmpr);
+    size_t copy_length = (size_t)length > DB_CMPR_PAGESIZE(db_io) ? DB_CMPR_PAGESIZE(db_io) : length;
     /*
      * We handle serious compression stuff only if we need to.
      * overflow! the compressed buffer is too big -> get extra page
@@ -486,8 +486,8 @@ CDB___memp_cmpr_write(dbmfp, bhp, db_io, niop)
     memcpy(db_io->buf + DB_CMPR_OVERHEAD, buffp, copy_length);
     buffp += copy_length;
     /* actual output  */
-    if((ret = CDB___os_io(dbenv, db_io, DB_IO_WRITE, niop)) != 0 ||
-       *niop != db_io->pagesize) {
+    if((ret = CDB___os_io(dbenv, db_io, DB_IO_WRITE, (size_t*)niop)) != 0 ||
+       (size_t)*niop != db_io->pagesize) {
       ret = EIO;
       goto err;
     }
@@ -596,6 +596,7 @@ CDB___memp_cmpr_inflate(dbenv, inbuff, inbuff_length, outbuff, outbuff_length, u
      int outbuff_length;
      void *user_data;
 {
+   if(dbenv||user_data){}
 #ifdef HAVE_LIBZ
   int ret = 0;
   z_stream c_stream;
@@ -641,7 +642,7 @@ CDB___memp_cmpr_deflate(dbenv, inbuff, inbuff_length, outbuffp, outbuff_lengthp,
      u_int8_t** outbuffp;
      int* outbuff_lengthp;
      void *user_data;
-{
+{	if(dbenv||user_data){}
 #ifdef HAVE_LIBZ
   int ret = 0;
   int r;
@@ -825,11 +826,11 @@ CDB___memp_cmpr_create(dbenv, fhp, pgsize, flags)
     return CDB___db_panic(dbenv, ret);
   }
   memcpy(buffer, (char*)&meta, sizeof(CMPRMETA));
-  if((ret = CDB___os_write(dbenv, fhp, buffer, pgsize, &count)) < 0) {
+  if((ret = CDB___os_write(dbenv, fhp, buffer, pgsize, (size_t*)&count)) < 0) {
     CDB___db_err(dbenv, "CDB___memp_cmpr_create: write error at 0");
     return CDB___db_panic(dbenv, ret);
   }
-  if(count != pgsize) {
+  if((size_t)count != pgsize) {
     CDB___db_err(dbenv, "CDB___memp_cmpr_create: write error %d bytes instead of %d bytes", count, pgsize);
     return CDB___db_panic(dbenv, EINVAL);
   }
@@ -863,7 +864,7 @@ CDB___memp_cmpr_open(dbenv, mfp, path)
     return CDB___db_panic(dbenv, ret);
   }
 
-  if((ret = CDB___os_read(dbenv, &fh, (void*)&meta, sizeof(CMPRMETA), &count)) != 0) {
+  if((ret = CDB___os_read(dbenv, &fh, (void*)&meta, sizeof(CMPRMETA), (size_t*)&count)) != 0) {
     CDB___db_err(dbenv, "CDB___memp_cmpr_open: cannot read page 0");
     ret = CDB___db_panic(dbenv, ret);
     goto err;
