@@ -8,7 +8,7 @@
 #include "config.h"
 
 #ifndef lint
-static const char revid[] = "$Id: qam.c,v 1.3 2000/06/28 16:47:02 loic Exp $";
+static const char revid[] = "$Id: qam.c,v 1.4 2014/04/17 20:27:33 sebdiaz Exp $";
 #endif /* not lint */
 
 #ifndef NO_SYSTEM_INCLUDES
@@ -150,7 +150,7 @@ CDB___qam_pitem(dbc, pagep, indx, recno, data)
 	DBT olddata, pdata, *datap;
 	QAMDATA *qp;
 	QUEUE *t;
-	u_int32_t size;
+	
 	u_int8_t *dest, *p;
 	int alloced, ret;
 
@@ -165,7 +165,7 @@ CDB___qam_pitem(dbc, pagep, indx, recno, data)
 	qp = QAM_GET_RECORD(dbp, pagep, indx);
 
 	p = qp->data;
-	size = data->size;
+	
 	datap = data;
 	if (F_ISSET(data, DB_DBT_PARTIAL)) {
 		if (data->doff + data->dlen > t->re_len) {
@@ -175,7 +175,7 @@ CDB___qam_pitem(dbc, pagep, indx, recno, data)
 		if (data->size != data->dlen) {
 len_err:		CDB___db_err(dbp->dbenv,
 			    "Length improper for fixed length record %lu",
-			    (u_long)(alloced ? alloced : data->size));
+			    (u_long)(alloced ? (u_long)alloced : (u_long)data->size));
 			return (EINVAL);
 		}
 		if (data->size == t->re_len)
@@ -256,7 +256,7 @@ __qam_c_put(dbc, key, data, flags, pgnop)
 	DBT *key, *data;
 	u_int32_t flags;
 	db_pgno_t *pgnop;
-{
+{	if(key){}
 	QUEUE_CURSOR *cp;
 	DB *dbp;
 	DB_LOCK lock;
@@ -497,7 +497,6 @@ __qam_c_del(dbc)
 {
 	QUEUE_CURSOR *cp;
 	DB *dbp;
-	DBT data;
 	DB_LOCK lock;
 	PAGE *pagep;
 	QAMDATA *qp;
@@ -537,8 +536,7 @@ __qam_c_del(dbc)
 	qp = QAM_GET_RECORD(dbp, pagep, cp->indx);
 
 	if (DB_LOGGING(dbc)) {
-		data.size = ((QUEUE *)dbp->q_internal)->re_len;
-		data.data = qp->data;
+	
 		if ((ret = CDB___qam_del_log(dbp->dbenv, dbc->txn,
 		    &LSN(pagep), 0, dbp->log_fileid, &LSN(pagep),
 		    pagep->pgno, cp->indx, cp->recno)) != 0)
@@ -1022,7 +1020,7 @@ __qam_c_close(dbc, root_pgno, rmroot)
 	DBC *dbc;
 	db_pgno_t root_pgno;
 	int *rmroot;
-{
+{	if(dbc||root_pgno||rmroot){}
 	QUEUE_CURSOR *cp;
 
 	COMPQUIET(root_pgno, 0);
