@@ -5,7 +5,7 @@
 // or the GNU General Public License version 2 or later
 // <http://www.gnu.org/copyleft/gpl.html>
 //
-// $Id: WordResults.h,v 1.3 2001/07/20 10:37:53 loic Exp $
+// $Id: WordResults.h,v 1.4 2001/08/31 14:06:04 loic Exp $
 //
 
 #ifndef _WordResults_h_
@@ -63,6 +63,9 @@ class WordResults
   int PutContext(const String& context_out);
   int GetContext(String& context_in) const;
 
+  int PutMatchesTotal(unsigned int matches_total);
+  int GetMatchesTotal(unsigned int& matches_total) const;
+
   int Count(unsigned int& count) const;
   
  private:
